@@ -29,7 +29,7 @@ describe 'tripleo::profile::base::docker' do
       it { is_expected.to contain_file('/etc/systemd/system/docker.service.d/99-unset-mountflags.conf') }
       it {
           is_expected.to contain_augeas('docker-sysconfig-options').with_changes([
-            "set OPTIONS '\"--log-driver=journald --signature-verification=false --iptables=false --live-restore\"'",
+            "set OPTIONS '\"--log-driver=journald --signature-verification=false --iptables=false\"'",
           ])
       }
     end
@@ -85,11 +85,9 @@ describe 'tripleo::profile::base::docker' do
       it { is_expected.to contain_service('docker') }
       it { is_expected.to contain_file('/etc/systemd/system/docker.service.d/99-unset-mountflags.conf') }
       it {
-        is_expected.to contain_augeas('docker-daemon.json').with_changes(
+        is_expected.to contain_augeas('docker-daemon.json-mirror').with_changes(
             ['set dict/entry[. = "registry-mirrors"] "registry-mirrors',
-             "set dict/entry[. = \"registry-mirrors\"]/array/string \"http://foo/bar\"",
-             'set dict/entry[. = "debug"] "debug"',
-             "set dict/entry[. = \"debug\"]/const \"false\""])
+             "set dict/entry[. = \"registry-mirrors\"]/array/string \"http://foo/bar\""])
       }
     end
 
@@ -104,9 +102,8 @@ describe 'tripleo::profile::base::docker' do
       it { is_expected.to contain_service('docker') }
       it { is_expected.to contain_file('/etc/systemd/system/docker.service.d/99-unset-mountflags.conf') }
       it {
-        is_expected.to contain_augeas('docker-daemon.json').with_changes(
-            ['rm dict/entry[. = "registry-mirrors"]',
-             'set dict/entry[. = "debug"] "debug"',
+        is_expected.to contain_augeas('docker-daemon.json-debug').with_changes(
+            ['set dict/entry[. = "debug"] "debug"',
              "set dict/entry[. = \"debug\"]/const \"true\""])
       }
     end
